.. _lmlib_api_reference:

API Reference
=============
Modules
-------

.. grid:: 2

    .. grid-item-card:: State-Space
        :link-type: ref
        :link: lmlib_api_statespace

        Recursive Least Square Approximation of Autonomous Linear State Space Models

    .. grid-item-card:: Polynomial
        :link-type: ref
        :link: lmlib_api_polynomial

        Efficient Polynomial Manipulations using Vector Exponent Notation

.. grid:: 2

    .. grid-item-card:: Utils
        :link-type: ref
        :link: lmlib_api_statespace

        Miscellaneous, Signal and Function Generators

Reference Content
-----------------

.. toctree::
    :maxdepth: 2

    self
    statespace
    polynomial
    utils
    Bibliography <bibliography>

